@@ -2307,10 +2307,7 @@ export default function waitUntil(callback, options = {}) {
     }
 
     #[test]
-    #[should_panic(
-        expected = "A string literal cannot be used as an imported binding.\n- Did you mean \
-                    `import { \"str\" as foo }`?"
-    )]
+    #[should_panic(expected = "A string literal cannot be used as an imported binding.")]
     fn error_for_string_literal_is_import_binding() {
         let src = "import { \"str\" } from \"mod\"";
         test_parser(src, Syntax::Es(Default::default()), |p| p.parse_module());
